@@ -140,7 +140,7 @@ class TemporalDictionaryEnsemble(BaseClassifier):
     >>> X_test, y_test = load_unit_test(split="test", return_X_y=True)
     >>> clf = TemporalDictionaryEnsemble(
     ...     n_parameter_samples=10,
-    ...     max_ensemble_size=5,
+    ...     max_ensemble_size=3,
     ...     randomly_selected_params=5,
     ... )
     >>> clf.fit(X_train, y_train)
@@ -540,9 +540,19 @@ class TemporalDictionaryEnsemble(BaseClassifier):
         return correct / train_size
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+            For classifiers, a "default" set of parameters should be provided for
+            general testing, and a "results_comparison" set for comparing against
+            previously recorded results if the general set does not produce suitable
+            probabilities to compare against.
+
         Returns
         -------
         params : dict or list of dict, default={}
@@ -551,12 +561,18 @@ class TemporalDictionaryEnsemble(BaseClassifier):
             `MyClass(**params)` or `MyClass(**params[i])` creates a valid test instance.
             `create_test_instance` uses the first (or only) dictionary in `params`.
         """
-        params = {
-            "n_parameter_samples": 5,
-            "max_ensemble_size": 2,
-            "randomly_selected_params": 3,
-        }
-        return params
+        if parameter_set == "results_comparison":
+            return {
+                "n_parameter_samples": 10,
+                "max_ensemble_size": 5,
+                "randomly_selected_params": 5,
+            }
+        else:
+            return {
+                "n_parameter_samples": 5,
+                "max_ensemble_size": 2,
+                "randomly_selected_params": 3,
+            }
 
 
 class IndividualTDE(BaseClassifier):
