@@ -9,7 +9,7 @@ __all__ = ["AutoARIMA", "ARIMA"]
 from sktime.forecasting.base.adapters._pmdarima import _PmdArimaAdapter
 from sktime.utils.validation._dependencies import _check_soft_dependencies
 
-_check_soft_dependencies("pmdarima")
+_check_soft_dependencies("pmdarima", severity="warning")
 
 
 class AutoARIMA(_PmdArimaAdapter):
@@ -224,6 +224,8 @@ class AutoARIMA(_PmdArimaAdapter):
     >>> y_pred = forecaster.predict(fh=[1,2,3])
     """  # noqa: E501
 
+    _tags = {"handles-missing-data": True}
+
     def __init__(
         self,
         start_p=2,
@@ -267,6 +269,8 @@ class AutoARIMA(_PmdArimaAdapter):
         **kwargs
     ):
 
+        _check_soft_dependencies("pmdarima", severity="error", object=self)
+
         self.start_p = start_p
         self.d = d
         self.start_q = start_q
@@ -356,9 +360,15 @@ class AutoARIMA(_PmdArimaAdapter):
         )
 
     @classmethod
-    def get_test_params(cls):
+    def get_test_params(cls, parameter_set="default"):
         """Return testing parameter settings for the estimator.
 
+        Parameters
+        ----------
+        parameter_set : str, default="default"
+            Name of the set of test parameters to return, for use in tests. If no
+            special parameters are defined for a value, will return `"default"` set.
+
         Returns
         -------
         params : dict or list of dict
@@ -557,6 +567,8 @@ class ARIMA(_PmdArimaAdapter):
     >>> y_pred = forecaster.predict(fh=[1,2,3])
     """  # noqa: E501
 
+    _tags = {"handles-missing-data": True}
+
     def __init__(
         self,
         order=(1, 0, 0),
@@ -572,6 +584,9 @@ class ARIMA(_PmdArimaAdapter):
         with_intercept=True,
         **sarimax_kwargs
     ):
+
+        _check_soft_dependencies("pmdarima", severity="error", object=self)
+
         self.order = order
         self.seasonal_order = seasonal_order
         self.start_params = start_params
