@@ -20,12 +20,14 @@ from sktime.utils.validation import (
     is_int,
     is_timedelta_or_date_offset,
 )
-from sktime.utils.validation.series import VALID_INDEX_TYPES
+from sktime.utils.validation.series import (
+    VALID_INDEX_TYPES,
+    is_in_valid_absolute_index_types,
+    is_in_valid_index_types,
+    is_in_valid_relative_index_types,
+    is_integer_index,
+)
 
-RELATIVE_TYPES = (pd.Int64Index, pd.RangeIndex, pd.TimedeltaIndex)
-ABSOLUTE_TYPES = (pd.Int64Index, pd.RangeIndex, pd.DatetimeIndex, pd.PeriodIndex)
-assert set(RELATIVE_TYPES).issubset(VALID_INDEX_TYPES)
-assert set(ABSOLUTE_TYPES).issubset(VALID_INDEX_TYPES)
 VALID_FORECASTING_HORIZON_TYPES = (int, list, np.ndarray, pd.Index)
 
 DELEGATED_METHODS = (
@@ -95,19 +97,20 @@ def _check_values(values: Union[VALID_FORECASTING_HORIZON_TYPES]) -> pd.Index:
     # isinstance() does not work here, because index types inherit from each
     # other,
     # hence we check for type equality here
-    if type(values) in VALID_INDEX_TYPES:
+    if is_in_valid_index_types(values):
         pass
 
-    # convert single integer to pandas index, no further checks needed
+    # convert single integer or timedelta or dateoffset
+    # to pandas index, no further checks needed
     elif is_int(values):
-        return pd.Int64Index([values], dtype=int)
+        values = pd.Index([values], dtype=int)
 
     elif is_timedelta_or_date_offset(values):
-        return pd.Index([values])
+        values = pd.Index([values])
 
     # convert np.array or list to pandas index
     elif is_array(values) and array_is_int(values):
-        values = pd.Int64Index(values, dtype=int)
+        values = pd.Index(values, dtype=int)
 
     elif is_array(values) and array_is_timedelta_or_date_offset(values):
         values = pd.Index(values)
@@ -140,7 +143,7 @@ class ForecastingHorizon:
 
     Parameters
     ----------
-    values : pd.Index, np.array, list or int
+    values : pd.Index, pd.TimedeltaIndex, np.array, list, pd.Timedelta, or int
         Values of forecasting horizon
     is_relative : bool, optional (default=None)
         - If True, a relative ForecastingHorizon is created:
@@ -181,17 +184,17 @@ class ForecastingHorizon:
         # types inherit from each other, hence we check for type equality
         error_msg = f"`values` type is not compatible with `is_relative={is_relative}`."
         if is_relative is None:
-            if type(values) in RELATIVE_TYPES:
+            if is_in_valid_relative_index_types(values):
                 is_relative = True
-            elif type(values) in ABSOLUTE_TYPES:
+            elif is_in_valid_absolute_index_types(values):
                 is_relative = False
             else:
                 raise TypeError(f"{type(values)} is not a supported fh index type")
         if is_relative:
-            if not type(values) in RELATIVE_TYPES:
+            if not is_in_valid_relative_index_types(values):
                 raise TypeError(error_msg)
         else:
-            if not type(values) in ABSOLUTE_TYPES:
+            if not is_in_valid_absolute_index_types(values):
                 raise TypeError(error_msg)
 
         self._values = values
@@ -206,7 +209,7 @@ class ForecastingHorizon:
 
         Parameters
         ----------
-        values : pd.Index, np.array, list or int
+        values : pd.Index, pd.TimedeltaIndex, np.array, list, pd.Timedelta, or int
             Values of forecasting horizon.
         is_relative : bool, default=same as self.is_relative
         - If None, determined automatically: same as self.is_relative
@@ -259,10 +262,6 @@ class ForecastingHorizon:
         """
         return self.to_pandas().to_numpy(**kwargs)
 
-    # We cache the results from `to_relative()` and `to_absolute()` calls to speed up
-    # computations, as these are the basic methods and often required internally when
-    # calling different methods.
-    @lru_cache(typed=True)
     def to_relative(self, cutoff=None):
         """Return forecasting horizon values relative to a cutoff.
 
@@ -277,49 +276,8 @@ class ForecastingHorizon:
         fh : ForecastingHorizon
             Relative representation of forecasting horizon.
         """
-        if self.is_relative:
-            return self._new()
+        return _to_relative(fh=self, cutoff=cutoff)
 
-        else:
-            absolute = self.to_pandas()
-            _check_cutoff(cutoff, absolute)
-
-            # We cannot use the freq from the ForecastingHorizon itself (or its
-            # wrapped pd.DatetimeIndex) because it may be none for non-regular
-            # indices, so instead we use the freq of cutoff.
-            freq = _get_freq(cutoff)
-
-            if isinstance(absolute, pd.DatetimeIndex):
-                # coerce to pd.Period for reliable arithmetics and computations of
-                # time deltas
-                absolute = _coerce_to_period(absolute, freq)
-                cutoff = _coerce_to_period(cutoff, freq)
-
-            # TODO: Replace the following line if the bug in pandas is fixed
-            #  and its version is restricted in sktime dependencies
-            # Compute relative values
-            # The following line circumvents the bug in pandas
-            # periods = pd.period_range(start="2021-01-01", periods=3, freq="2H")
-            # periods - periods[0]
-            # Out: Index([<0 * Hours>, <4 * Hours>, <8 * Hours>], dtype = 'object')
-            # [v - periods[0] for v in periods]
-            # Out: Index([<0 * Hours>, <2 * Hours>, <4 * Hours>], dtype='object')
-            # TODO: v0.12.0: Check if this comment below can be removed,
-            # so check if pandas has released the fix to PyPI:
-            # This bug was reported: https://github.com/pandas-dev/pandas/issues/45999
-            # and fixed: https://github.com/pandas-dev/pandas/pull/46006
-            # Most likely it will be released with pandas 1.5
-            # Once the bug is fixed the line should simply be:
-            # relative = absolute - cutoff
-            relative = pd.Index([date - cutoff for date in absolute])
-
-            # Coerce durations (time deltas) into integer values for given frequency
-            if isinstance(absolute, (pd.PeriodIndex, pd.DatetimeIndex)):
-                relative = _coerce_duration_to_int(relative, freq=freq)
-
-            return self._new(relative, is_relative=True)
-
-    @lru_cache(typed=True)
     def to_absolute(self, cutoff):
         """Return absolute version of forecasting horizon values.
 
@@ -334,26 +292,7 @@ class ForecastingHorizon:
         fh : ForecastingHorizon
             Absolute representation of forecasting horizon.
         """
-        if not self.is_relative:
-            return self._new()
-
-        else:
-            relative = self.to_pandas()
-            _check_cutoff(cutoff, relative)
-            is_timestamp = isinstance(cutoff, pd.Timestamp)
-
-            if is_timestamp:
-                # coerce to pd.Period for reliable arithmetic operations and
-                # computations of time deltas
-                cutoff = _coerce_to_period(cutoff, freq=cutoff.freqstr)
-
-            absolute = cutoff + relative
-
-            if is_timestamp:
-                # coerce back to DatetimeIndex after operation
-                absolute = absolute.to_timestamp(cutoff.freqstr)
-
-            return self._new(absolute, is_relative=False)
+        return _to_absolute(fh=self, cutoff=cutoff)
 
     def to_absolute_int(self, start, cutoff=None):
         """Return absolute values as zero-based integer index starting from `start`.
@@ -444,11 +383,13 @@ class ForecastingHorizon:
         out_of_sample = self.to_pandas()[is_out_of_sample]
         return self._new(out_of_sample)
 
-    def _is_in_sample(self, cutoff=None):
+    def _is_in_sample(self, cutoff=None) -> np.ndarray:
         """Get index location of in-sample values."""
-        return self.to_relative(cutoff).to_pandas() <= 0
+        relative = self.to_relative(cutoff).to_pandas()
+        null = 0 if is_integer_index(relative) else pd.Timedelta(0)
+        return relative <= null
 
-    def is_all_in_sample(self, cutoff=None):
+    def is_all_in_sample(self, cutoff=None) -> bool:
         """Whether the forecasting horizon is purely in-sample for given cutoff.
 
         Parameters
@@ -463,12 +404,11 @@ class ForecastingHorizon:
         """
         return sum(self._is_in_sample(cutoff)) == len(self)
 
-    def _is_out_of_sample(self, cutoff=None):
+    def _is_out_of_sample(self, cutoff=None) -> np.ndarray:
         """Get index location of out-of-sample values."""
-        # return ~self._in_sample_idx(cutoff)
-        return self.to_relative(cutoff).to_pandas() > 0
+        return np.logical_not(self._is_in_sample(cutoff))
 
-    def is_all_out_of_sample(self, cutoff=None):
+    def is_all_out_of_sample(self, cutoff=None) -> bool:
         """Whether the forecasting horizon is purely out-of-sample for given cutoff.
 
         Parameters
@@ -504,7 +444,16 @@ class ForecastingHorizon:
             Indexer.
         """
         if from_cutoff:
-            return self.to_relative(cutoff).to_pandas() - 1
+            relative_index = self.to_relative(cutoff).to_pandas()
+            if is_integer_index(relative_index):
+                return relative_index - 1
+            else:
+                # What does indexer mean if fh is timedelta?
+                msg = (
+                    "The indexer for timedelta-like forecasting horizon "
+                    "is not yet implemented"
+                )
+                raise NotImplementedError(msg)
         else:
             relative = self.to_relative(cutoff)
             return relative - relative.to_pandas()[0]
@@ -516,6 +465,114 @@ class ForecastingHorizon:
         return f"{class_name}({pandas_repr}, is_relative={self.is_relative})"
 
 
+# This function needs to be outside ForecastingHorizon
+# since the lru_cache decorator has known, problematic interactions
+# with object methods, see B019 error of flake8-bugbear for a detail explanation.
+# See more here: https://github.com/alan-turing-institute/sktime/issues/2338
+# We cache the results from `to_relative()` and `to_absolute()` calls to speed up
+# computations, as these are the basic methods and often required internally when
+# calling different methods.
+@lru_cache(typed=True)
+def _to_relative(fh: ForecastingHorizon, cutoff=None) -> ForecastingHorizon:
+    """Return forecasting horizon values relative to a cutoff.
+
+    Parameters
+    ----------
+    fh : ForecastingHorizon
+    cutoff : pd.Period, pd.Timestamp, int, optional (default=None)
+        Cutoff value required to convert a relative forecasting
+        horizon to an absolute one (and vice versa).
+
+    Returns
+    -------
+    fh : ForecastingHorizon
+        Relative representation of forecasting horizon.
+    """
+    if fh.is_relative:
+        return fh._new()
+
+    else:
+        absolute = fh.to_pandas()
+        _check_cutoff(cutoff, absolute)
+
+        # We cannot use the freq from the ForecastingHorizon itself (or its
+        # wrapped pd.DatetimeIndex) because it may be none for non-regular
+        # indices, so instead we use the freq of cutoff.
+        freq = _get_freq(cutoff)
+
+        if isinstance(absolute, pd.DatetimeIndex):
+            # coerce to pd.Period for reliable arithmetics and computations of
+            # time deltas
+            absolute = _coerce_to_period(absolute, freq)
+            cutoff = _coerce_to_period(cutoff, freq)
+
+        # TODO: Replace when we upgrade our lower pandas bound
+        #  to a version where this is fixed
+        # Compute relative values
+        # The following line circumvents the bug in pandas
+        # periods = pd.period_range(start="2021-01-01", periods=3, freq="2H")
+        # periods - periods[0]
+        # Out: Index([<0 * Hours>, <4 * Hours>, <8 * Hours>], dtype = 'object')
+        # [v - periods[0] for v in periods]
+        # Out: Index([<0 * Hours>, <2 * Hours>, <4 * Hours>], dtype='object')
+        # TODO: v0.12.0: Check if this comment below can be removed,
+        # so check if pandas has released the fix to PyPI:
+        # This bug was reported: https://github.com/pandas-dev/pandas/issues/45999
+        # and fixed: https://github.com/pandas-dev/pandas/pull/46006
+        # Most likely it will be released with pandas 1.5
+        # Once the bug is fixed the line should simply be:
+        # relative = absolute - cutoff
+        relative = pd.Index([date - cutoff for date in absolute])
+
+        # Coerce durations (time deltas) into integer values for given frequency
+        if isinstance(absolute, (pd.PeriodIndex, pd.DatetimeIndex)):
+            relative = _coerce_duration_to_int(relative, freq=freq)
+
+        return fh._new(relative, is_relative=True)
+
+
+# This function needs to be outside ForecastingHorizon
+# since the lru_cache decorator has known, problematic interactions
+# with object methods, see B019 error of flake8-bugbear for a detail explanation.
+# See more here: https://github.com/alan-turing-institute/sktime/issues/2338
+@lru_cache(typed=True)
+def _to_absolute(fh: ForecastingHorizon, cutoff) -> ForecastingHorizon:
+    """Return absolute version of forecasting horizon values.
+
+    Parameters
+    ----------
+    fh : ForecastingHorizon
+    cutoff : pd.Period, pd.Timestamp, int
+        Cutoff value is required to convert a relative forecasting
+        horizon to an absolute one (and vice versa).
+
+    Returns
+    -------
+    fh : ForecastingHorizon
+        Absolute representation of forecasting horizon.
+    """
+    if not fh.is_relative:
+        return fh._new()
+
+    else:
+        relative = fh.to_pandas()
+        _check_cutoff(cutoff, relative)
+        is_timestamp = isinstance(cutoff, pd.Timestamp)
+
+        if is_timestamp:
+            # coerce to pd.Period for reliable arithmetic operations and
+            # computations of time deltas
+            cutoff = _coerce_to_period(cutoff, freq=cutoff.freqstr)
+
+        absolute = cutoff + relative
+
+        if is_timestamp:
+            # coerce back to DatetimeIndex after operation
+            absolute = absolute.to_timestamp(cutoff.freqstr)
+
+        return fh._new(absolute, is_relative=False)
+
+
 def _check_cutoff(cutoff, index):
     """Check if the cutoff is valid based on time index of forecasting horizon.
 
